pub struct TestAuthContext {
pub sub: String,
pub iss: String,
pub aud: String,
pub kid: String,
pub exp: u64,
}Expand description
Typed auth context inserted by helpers and extracted in handlers.
Fields
sub: Stringiss: Stringaud: Stringkid: Stringexp: u64Trait Implementations
Sourceimpl Clone for TestAuthContext
impl Clone for TestAuthContext
Sourcefn clone(&self) -> TestAuthContext
fn clone(&self) -> TestAuthContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestAuthContext
impl Debug for TestAuthContext
Sourceimpl<'de> Deserialize<'de> for TestAuthContext
impl<'de> Deserialize<'de> for TestAuthContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<S> FromRequestParts<S> for TestAuthContext
impl<S> FromRequestParts<S> for TestAuthContext
Sourceimpl PartialEq for TestAuthContext
impl PartialEq for TestAuthContext
Sourcefn eq(&self, other: &TestAuthContext) -> bool
fn eq(&self, other: &TestAuthContext) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TestAuthContext
impl Serialize for TestAuthContext
impl Eq for TestAuthContext
impl StructuralPartialEq for TestAuthContext